// ArduinoJson - https://arduinojson.org
// Copyright Benoit Blanchon 2014-2021
// MIT License

#pragma once

namespace ARDUINOJSON_NAMESPACE {

template <class = void>
struct make_void {
  typedef void type;
};

}  // namespace ARDUINOJSON_NAMESPACE
